@@ -41,7 +41,7 @@
 #' @param cache optional drake cache. See code{\link{new_cache}()}.
 #' The \code{cache} argument is ignored if a
 #' non-null \code{config} argument is supplied.
-#' @param parallelism samea as for \code{\link{make}}. Used
+#' @param parallelism same as for \code{\link{make}}. Used
 #' to parallelize import objects.
 #' @param jobs same as for \code{\link{make}}, just used to
 #' process imports
@@ -53,30 +53,32 @@
 #' @param config option internal runtime parameter list of
 #' \code{\link{make}(...)},
 #' produced with \code{\link{config}()}.
-#' Computing this
+#' Overrides all arguments except \code{from_scratch},
+#' \code{targets_only}, and \code{digits}.
+#' Computing \code{config}
 #' in advance could save time if you plan multiple calls to
 #' this function.
 #' @param digits number of digits for rounding the times.
-#' @param path file path to the folder contianing the cache.
+#' @param path file path to the folder containing the cache.
 #' Yes, this is the parent directory containing the cache,
 #' not the cache itself.
 #' @param search logical, whether to search back in the file system
 #' for the cache.
 predict_runtime <- function(
-  plan,
+  plan = drake::plan(),
   from_scratch = FALSE,
   targets_only = FALSE,
   targets = drake::possible_targets(plan),
   envir = parent.frame(),
   verbose = TRUE,
-  cache = NULL,
+  cache = drake::get_cache(path = path, search = search),
   parallelism = drake::default_parallelism(),
   jobs = 1,
   future_jobs = jobs,
   packages = (.packages()),
   prework = character(0),
   config = NULL,
-  digits = 0,
+  digits = 3,
   path = getwd(),
   search = TRUE
 ){
@@ -160,7 +162,7 @@ predict_runtime <- function(
 #' @param targets Targets to build in the workflow.
 #' Timing information is
 #' limited to these targets and their dependencies.
-#' @param envir same as for \code{\link{make}}. Supercedes
+#' @param envir same as for \code{\link{make}}. Supersedes
 #' \code{config$envir}.
 #' @param verbose same as for \code{\link{make}}
 #' @param cache optional drake cache. See code{\link{new_cache}()}.
@@ -178,31 +180,32 @@ predict_runtime <- function(
 #' @param config option internal runtime parameter list of
 #' \code{\link{make}(...)},
 #' produced with \code{\link{config}()}.
-#' \code{config$envir} is ignored.
-#' Otherwise, computing this
+#' Overrides all arguments except \code{from_scratch},
+#' \code{targets_only}, and \code{digits}.
+#' Computing \code{config}
 #' in advance could save time if you plan multiple calls to
 #' this function.
 #' @param digits number of digits for rounding the times.
-#' @param path file path to the folder contianing the cache.
+#' @param path file path to the folder containing the cache.
 #' Yes, this is the parent directory containing the cache,
 #' not the cache itself.
 #' @param search logical, whether to search back in the file system
 #' for the cache.
 rate_limiting_times <- function(
-  plan,
+  plan = drake::plan(),
   from_scratch = FALSE,
   targets_only = FALSE,
   targets = drake::possible_targets(plan),
   envir = parent.frame(),
   verbose = TRUE,
-  cache = NULL,
+  cache = drake::get_cache(path = path, search = search),
   parallelism = drake::default_parallelism(),
   jobs = 1,
   future_jobs = jobs,
   packages = (.packages()),
   prework = character(0),
   config = NULL,
-  digits = 0,
+  digits = 3,
   path = getwd(),
   search = TRUE
 ){
@@ -259,7 +262,7 @@ rate_limiting_times <- function(
   }
   keep_these <- setdiff(keys, rownames(times))
   graph <- delete_vertices(config$graph, v = keep_these)
-  times <- resolve_levels(nodes = times, graph = graph)
+  times <- resolve_levels(config = list(nodes = times, graph = graph))
   colnames(times) <- gsub("^level$", "stage", colnames(times))
   ddply(times, "stage", rate_limiting_at_stage, future_jobs = future_jobs) %>%
     round_times(digits = digits) %>%
