@@ -15,74 +15,6 @@ unlink(c("Makefile", "report.Rmd", "shell.sh", "STDIN.o*", "Thumbs.db"))
 #  examples_drake() # List the other examples.
 #  vignette("quickstart") # This vignette
 
-## ----examplesquick, eval = FALSE-----------------------------------------
-#  load_basic_example()
-#  drake_tip()
-#  examples_drake()
-#  example_drake()
-
-## ----planquick, eval = FALSE---------------------------------------------
-#  plan()
-#  analyses()
-#  summaries()
-#  evaluate()
-#  expand()
-#  gather()
-#  wildcard() # from the wildcard package
-
-## ----depquick, eval = FALSE----------------------------------------------
-#  outdated()
-#  missed()
-#  plot_graph()
-#  dataframes_graph()
-#  render_graph()
-#  read_graph()
-#  deps()
-#  tracked()
-
-## ----cachequicklist, eval = FALSE----------------------------------------
-#  clean()
-#  cached()
-#  imported()
-#  built()
-#  readd()
-#  loadd()
-#  find_project()
-#  find_cache()
-
-## ----timesquick, eval = FALSE--------------------------------------------
-#  build_times()
-#  predict_runtime()
-#  rate_limiting_times()
-
-## ----speedquick, eval = FALSE--------------------------------------------
-#  make() # with jobs > 2
-#  max_useful_jobs()
-#  parallelism_choices()
-#  shell_file()
-
-## ----cachequick, eval = FALSE--------------------------------------------
-#  available_hash_algos()
-#  cache_path()
-#  cache_types()
-#  configure_cache()
-#  default_long_hash_algo()
-#  default_short_hash_algo()
-#  long_hash()
-#  short_hash()
-#  new_cache()
-#  recover_cache()
-#  this_cache()
-#  type_of_cache()
-
-## ----debugquick, eval = FALSE--------------------------------------------
-#  check()
-#  session()
-#  in_progress()
-#  progress()
-#  config()
-#  read_config()
-
 ## ----libs----------------------------------------------------------------
 library(knitr)
 library(drake)
@@ -105,11 +37,6 @@ reg2 <- function(d){
   lm(y ~ x2, data = d)
 }
 
-## ----knit----------------------------------------------------------------
-my_knit <- function(file, ...){
-  knit(file)
-}
-
 ## ----file----------------------------------------------------------------
 lines <- c(
   "---",
@@ -119,6 +46,12 @@ lines <- c(
   "---",
   "",
   "Look how I read outputs from the drake cache.",
+  "Drake notices that `small`, `coef_regression2_small`,",
+  "and `large` are dependencies of the",
+  "future compiled output report file target, `report.md`.",
+  "Just be sure that the workflow plan command for the target `'report.md'`",
+  "has an explicit call to `knit()`, something like `knit('report.Rmd')` or",
+  "`knitr::knit(input = 'report.Rmd', quiet = TRUE)`.",
   "",
   "```{r example_chunk}",
   "library(drake)",
@@ -140,7 +73,7 @@ my_plan
 ## ----checkdeps-----------------------------------------------------------
 deps(reg2)
 deps(my_plan$command[1]) # Files like report.Rmd are single-quoted.
-deps(my_plan$command[16])
+deps(my_plan$command[nrow(my_plan)])
 
 ## ----tracked-------------------------------------------------------------
 tracked(my_plan, targets = "small")
@@ -160,8 +93,8 @@ expand(my_datasets, values = c("rep1", "rep2"))
 
 ## ----methods-------------------------------------------------------------
 methods <- plan(
-  regression1 = reg1(..dataset..),
-  regression2 = reg2(..dataset..))
+  regression1 = reg1(..dataset..), # nolint
+  regression2 = reg2(..dataset..)) # nolint
 methods
 
 ## ----analyses------------------------------------------------------------
@@ -170,27 +103,22 @@ my_analyses
 
 ## ----summaries-----------------------------------------------------------
 summary_types <- plan(
-  summ = suppressWarnings(summary(..analysis..)),
-  coef = coef(..analysis..))
+  summ = suppressWarnings(summary(..analysis..)), # nolint
+  coef = coefficients(..analysis..)) # nolint
 summary_types
 
 results <- summaries(summary_types, analyses = my_analyses,
   datasets = my_datasets, gather = NULL)
 results
 
-## ----reportdeps----------------------------------------------------------
-load_in_report <- plan(
-  report_dependencies = c(small, large, coef_regression2_small))
-load_in_report
-
 ## ----reportplan----------------------------------------------------------
 report <- plan(
-  report.md = my_knit('report.Rmd', report_dependencies), # nolint
+  report.md = knit('report.Rmd', quiet = TRUE), # nolint
   file_targets = TRUE, strings_in_dots = "filenames")
 report
 
 ## ----wholeplan-----------------------------------------------------------
-my_plan <- rbind(report, my_datasets, load_in_report, my_analyses, results)
+my_plan <- rbind(report, my_datasets, my_analyses, results)
 my_plan
 
 ## ----more_expansions_and_plans-------------------------------------------
@@ -213,7 +141,7 @@ missed(my_plan, verbose = FALSE) # Checks your workspace.
 make(my_plan)
 
 ## ----autoload------------------------------------------------------------
-"report_dependencies" %in% ls() # Should be TRUE.
+ls()
 
 ## ----plotgraphfirstmake--------------------------------------------------
 outdated(my_plan, verbose = FALSE) # Everything is up to date.
@@ -285,54 +213,6 @@ clean(small, reg1) # uncaches individual targets and imported objects
 clean() # cleans all targets out of the cache
 clean(destroy = TRUE) # removes the cache entirely
 
-## ----plotgraph-----------------------------------------------------------
-clean()
-load_basic_example()
-make(my_plan, jobs = 2, verbose = FALSE) # Parallelize over 2 jobs.
-# Change a dependency.
-reg2 <- function(d) {
-  d$x3 <- d$x ^ 3
-  lm(y ~ x3, data = d)
-}
-
-## ----graph4quick, eval = FALSE-------------------------------------------
-#  # Hover, click, drag, zoom, and pan.
-#  plot_graph(my_plan, width = "100%", height = "500px")
-
-## ----hpcquick, eval = FALSE----------------------------------------------
-#  library(drake)
-#  load_basic_example()
-#  plot_graph(my_plan) # Set targets_only to TRUE for smaller graphs.
-#  max_useful_jobs(my_plan) # 8
-#  max_useful_jobs(my_plan, imports = "files") # 8
-#  max_useful_jobs(my_plan, imports = "all") # 10
-#  max_useful_jobs(my_plan, imports = "none") # 8
-#  make(my_plan, jobs = 4)
-#  plot_graph(my_plan)
-#  # Ignore the targets already built.
-#  max_useful_jobs(my_plan) # 1
-#  max_useful_jobs(my_plan, imports = "files") # 1
-#  max_useful_jobs(my_plan, imports = "all") # 10
-#  max_useful_jobs(my_plan, imports = "none") # 0
-#  # Change a function so some targets are now out of date.
-#  reg2 <- function(d){
-#    d$x3 <- d$x ^ 3
-#    lm(y ~ x3, data = d)
-#  }
-#  plot_graph(my_plan)
-#  max_useful_jobs(my_plan) # 4
-#  max_useful_jobs(my_plan, from_scratch = TRUE) # 8
-#  max_useful_jobs(my_plan, imports = "files") # 4
-#  max_useful_jobs(my_plan, imports = "all") # 10
-#  max_useful_jobs(my_plan, imports = "none") # 4
-
-## ----cluster, eval = FALSE-----------------------------------------------
-#  make(my_plan, parallelism = "Makefile", jobs = 4,
-#    prepend = "SHELL=srun")
-
-## ----makefileargsquick, eval = FALSE-------------------------------------
-#  make(..., parallelism = "Makefile", jobs = 2, args = "--jobs=4")
-
 ## ----endofline_quickstart, echo = F--------------------------------------
 clean(destroy = TRUE)
 unlink(c("Makefile", "report.Rmd", "shell.sh", "STDIN.o*", "Thumbs.db"))
