@@ -1,5 +1,4 @@
-cat(get_testing_scenario_name(), ": ", sep = "")
-context("examples")
+drake_context("examples")
 
 test_with_dir("examples are listed and written", {
   x <- examples_drake()
