@@ -1,5 +1,4 @@
-cat(get_testing_scenario_name(), ": ", sep = "")
-context("generate")
+drake_context("generate")
 
 test_with_dir("empty generative args", {
   x <- plan(a = 1, b = FUNCTION())
@@ -63,12 +62,9 @@ test_with_dir("evaluate, expand, and gather", {
   expect_equal(x4, y)
 
   x5 <- evaluate(x, rules = list(MU = 1:2, SIGMA = c(0.1, 1, 10)))
-  expect_equal(
-    12,
-    nrow(x5),
-    length(unique(x5$target)),
-    length(unique(x5$command))
-  )
+  expect_equal(12, nrow(x5))
+  expect_equal(12, length(unique(x5$target)))
+  expect_equal(6, length(unique(x5$command)))
 
   x6 <- gather(x)
   y <- data.frame(
@@ -115,7 +111,7 @@ test_with_dir("analyses and summaries", {
 
   no_analyses <- plan(
     summ = summary(..dataset..), # nolint
-    coef = coef(..dataset..) # nolint
+    coef = coefficients(..dataset..) # nolint
   )
   suppressWarnings(
     expect_error(
@@ -125,7 +121,7 @@ test_with_dir("analyses and summaries", {
 
   summary_types <- plan(
     summ = summary(..analysis..), # nolint
-    coef = coef(..analysis..) # nolint
+    coef = coefficients(..analysis..) # nolint
   )
   results <- summaries(summary_types, analyses, datasets, gather = NULL)
   x <- data.frame(
@@ -144,10 +140,10 @@ test_with_dir("analyses and summaries", {
       "summary(regression1_large)",
       "summary(regression2_small)",
       "summary(regression2_large)",
-      "coef(regression1_small)",
-      "coef(regression1_large)",
-      "coef(regression2_small)",
-      "coef(regression2_large)"
+      "coefficients(regression1_small)",
+      "coefficients(regression1_large)",
+      "coefficients(regression2_small)",
+      "coefficients(regression2_large)"
     ),
     stringsAsFactors = FALSE
   )
@@ -155,7 +151,7 @@ test_with_dir("analyses and summaries", {
 
   summary_types <- plan(
     summ = summary(..analysis.., ..dataset..), # nolint
-    coef = coef(..analysis..) # nolint
+    coef = coefficients(..analysis..) # nolint
   )
   results <- summaries(
     summary_types,
@@ -179,10 +175,10 @@ test_with_dir("analyses and summaries", {
       "summary(regression1_large, large)",
       "summary(regression2_small, small)",
       "summary(regression2_large, large)",
-      "coef(regression1_small)",
-      "coef(regression1_large)",
-      "coef(regression2_small)",
-      "coef(regression2_large)"
+      "coefficients(regression1_small)",
+      "coefficients(regression1_large)",
+      "coefficients(regression2_small)",
+      "coefficients(regression2_large)"
     ),
     stringsAsFactors = FALSE
   )
