@@ -1,5 +1,4 @@
-cat(get_testing_scenario_name(), ": ", sep = "")
-context("import file")
+drake_context("import file")
 
 test_with_dir("responses to imported file", {
   config <- dbug()
